@@ -1,5 +1,5 @@
 /* client.c --- SASL mechanism GSSAPI as defined in RFC 2222, client side.
- * Copyright (C) 2002, 2003, 2004, 2005  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -46,10 +46,6 @@
 # endif
 #endif
 
-#ifdef HAVE_NETINET_IN_H
-# include <netinet/in.h>
-#endif
-
 struct _Gsasl_gssapi_client_state
 {
   int step;
@@ -263,6 +259,9 @@ _gsasl_gssapi_client_finish (Gsasl_session * sctx, void *mech_data)
   _Gsasl_gssapi_client_state *state = mech_data;
   OM_uint32 maj_stat, min_stat;
 
+  if (!state)
+    return;
+
   if (state->service != GSS_C_NO_NAME)
     maj_stat = gss_release_name (&min_stat, &state->service);
   if (state->context != GSS_C_NO_CONTEXT)
